@@ -103,7 +103,7 @@ def get_people(html):
 
 
 def parser():
-    log.debug(f"The script {os.path.splitext('path_to_file')[0]} stops working")
+    log.debug(f"The script {__name__} starts working")
     html_links = f.get_html(URL_COMMITTEE)
     if html_links.status_code == 200:
         links = get_links(html_links.text)
