@@ -57,7 +57,7 @@ def get_content(URL, name):
 
 
 def parser():
-    log.debug(f"The script {os.path.splitext('path_to_file')[0]} stops working")
+    log.debug(f"The script {__name__} starts working")
     html = f.get_html(URL_1)
     people = []
     if html.status_code == 200:
